@@ -42,7 +42,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include "cpp_common/basePath_SSEC.hpp"
 #include "trsp/edgeInfo.h"
-#include "cpp_common/rule.h"
+#include "cpp_common/rule.hpp"
 #include "cpp_common/pgr_messages.h"
 
 namespace pgrouting {
