@@ -118,6 +118,27 @@ COST 100
 ROWS 1000;
 
 
+-- COMBINATIONS
+--v3.2
+CREATE FUNCTION pgr_bdDijkstraCost(
+    TEXT,     -- edges_sql (required)
+    TEXT,     -- combinations_sql (required)
+
+    directed BOOLEAN DEFAULT true,
+
+    OUT start_vid BIGINT,
+    OUT end_vid BIGINT,
+    OUT agg_cost FLOAT)
+RETURNS SETOF RECORD AS
+$BODY$
+    SELECT a.start_vid, a.end_vid, a.agg_cost
+    FROM _pgr_bdDijkstra(_pgr_get_statement($1), _pgr_get_statement($2), directed, true) as a;
+$BODY$
+LANGUAGE SQL VOLATILE STRICT
+COST 100
+ROWS 1000;
+
+
 -- COMMENTS
 
 COMMENT ON FUNCTION pgr_bdDijkstraCost(TEXT, BIGINT, BIGINT, BOOLEAN)
@@ -170,3 +191,14 @@ IS 'pgr_bdDijkstraCost(Many to Many)
 - Documentation:
   - ${PROJECT_DOC_LINK}/pgr_bdDijkstraCost.html
 ';
+
+COMMENT ON FUNCTION pgr_bdDijkstraCost(TEXT, TEXT, BOOLEAN)
+IS 'pgr_bdDijkstraCost(Combinations)
+- Parameters:
+  - Edges SQL with columns: id, source, target, cost [,reverse_cost]
+  - Combinations SQL with columns: source, target
+- Optional Parameters
+  - directed := true
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdDijkstraCost.html
+';
