@@ -1,4 +1,5 @@
 /*PGR-GNU*****************************************************************
+File: pgr_maxflow.cpp
 
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
@@ -84,7 +85,7 @@ void PgrFlowGraph::insert_edges_push_relabel(
                 boost::add_edge(v2, v1, graph);
             E_to_id.insert(std::pair<E, int64_t>(e1, edge.id));
             E_to_id.insert(std::pair<E, int64_t>(e1_rev, edge.id));
-            capacity[e1] = (int64_t) edge.cost;
+            capacity[e1] = static_cast<int64_t>(edge.cost);
             capacity[e1_rev] = 0;
             rev[e1] = e1_rev;
             rev[e1_rev] = e1;
@@ -95,7 +96,7 @@ void PgrFlowGraph::insert_edges_push_relabel(
                 boost::add_edge(v1, v2, graph);
             E_to_id.insert(std::pair<E, int64_t>(e2, edge.id));
             E_to_id.insert(std::pair<E, int64_t>(e2_rev, edge.id));
-            capacity[e2] = (int64_t) edge.reverse_cost;
+            capacity[e2] = static_cast<int64_t>(edge.reverse_cost);
             capacity[e2_rev] = 0;
             rev[e2] = e2_rev;
             rev[e2_rev] = e2;
@@ -118,9 +119,9 @@ void PgrFlowGraph::insert_edges(
             boost::add_edge(v2, v1, graph);
         E_to_id.insert(std::pair<E, int64_t>(e, edge.id));
         E_to_id.insert(std::pair<E, int64_t>(e_rev, edge.id));
-        capacity[e] = edge.cost > 0 ? (int64_t) edge.cost : 0;
+        capacity[e] = edge.cost > 0 ? static_cast<int64_t>(edge.cost) : 0;
         capacity[e_rev] = edge.reverse_cost > 0
-            ? (int64_t) edge.reverse_cost : 0;
+            ? static_cast<int64_t>(edge.reverse_cost) : 0;
         rev[e] = e_rev;
         rev[e_rev] = e;
     }
@@ -210,7 +211,7 @@ PgrFlowGraph::get_flow_edges() const {
         if (((capacity[*e] - residual_capacity[*e]) > 0) &&
                 ((*e).m_source != supersource) &&
                 ((*e).m_target != supersink)) {
-            Flow_t edge;
+            Flow_t edge = {};
             edge.edge = get_edge_id(*e);
             edge.source = get_vertex_id((*e).m_source);
             edge.target = get_vertex_id((*e).m_target);
@@ -280,8 +281,7 @@ PgrFlowGraph::get_edge_disjoint_paths(
         bool exists;
         size_t j;
         for (j = 0; j < size - 1; j++) {
-            Path_rt edge;
-            edge.seq = static_cast<int>(j + 1);
+            Path_rt edge = {};
             edge.start_id = paths[i][0];
             edge.end_id = paths[i][size - 1];
             edge.node = paths[i][j];
@@ -291,8 +291,7 @@ PgrFlowGraph::get_edge_disjoint_paths(
             edge.edge = get_edge_id(e);
             path_elements.push_back(edge);
         }
-        Path_rt edge;
-        edge.seq = static_cast<int>(j + 1);
+        Path_rt edge = {};
         edge.start_id = paths[i][0];
         edge.end_id = paths[i][size - 1];
         edge.node = paths[i][j];
