@@ -33,7 +33,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "withPoints/pgr_withPoints.hpp"
 #include "c_types/routes_t.h"
 #include "c_types/restriction_t.h"
-#include "cpp_common/rule.h"
+#include "cpp_common/rule.hpp"
 #include "cpp_common/combinations.h"
 #include "cpp_common/pgr_alloc.hpp"
 #include "cpp_common/pgr_assert.h"
@@ -55,7 +55,9 @@ post_process_trspvia(std::deque<pgrouting::Path> &paths, std::vector<int64_t> vi
     auto u = via.front();
     bool skip = true;
     for (const auto &v : via) {
-        if (skip) {skip = false; continue;}
+        if (skip) {
+            skip = false; continue;
+        }
         /*
          * look for the path (u,v)
          */
