@@ -40,7 +40,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <cassert>
 
 #include "trsp/pgr_trspHandler.h"
-#include "cpp_common/rule.h"
+#include "cpp_common/rule.hpp"
 #include "cpp_common/pgr_assert.h"
 #include "cpp_common/pgr_alloc.hpp"
 #include "cpp_common/combinations.h"
