@@ -48,15 +48,18 @@ if test -z "$DIRECTORY"; then
     echo "--------------------"
     echo "------   *.c  ------"
     echo "--------------------"
-    code_linter/cpplint/cpplint.py --extensions=c  --linelength=120 --filter=-readability/casting src/*/*.c
+    code_linter/cpplint/cpplint.py --extensions=c --linelength=120 --filter=-readability/casting,-whitespace/newline src/*/*.c
     echo "--------------------"
     echo "------ *.cpp  ------"
     echo "--------------------"
-    code_linter/cpplint/cpplint.py --filter=-runtime/references  --linelength=120 src/*/*.cpp
+    code_linter/cpplint/cpplint.py --linelength=120 \
+        --filter=-runtime/references,-whitespace/indent_namespace \
+        src/*/*.cpp
     echo "--------------------"
     echo "------ HEADERS  ------"
     echo "--------------------"
-    code_linter/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h  --linelength=120 --filter=-runtime/references \
+    code_linter/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h  --linelength=120 \
+        --filter=-runtime/references,-whitespace/indent_namespace \
         include/*/*.h* \
         include/*/*/*.h*
 
@@ -66,7 +69,8 @@ else
     echo "--------------------"
     echo "------ IN PLACE HEADERS  ------"
     echo "--------------------"
-    code_linter/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h  --linelength=120 --filter=-runtime/references \
+    code_linter/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h  --linelength=120 \
+        --filter=-runtime/references \
         include/*/*.h* \
         include/*/*/*.h*
 
@@ -74,11 +78,16 @@ else
         echo "--------------------"
         echo "------   *.c  ------"
         echo "--------------------"
-        code_linter/cpplint/cpplint.py --extensions=c  --linelength=120 --filter=-readability/casting src/"$DIRECTORY"/*.c
+        code_linter/cpplint/cpplint.py --extensions=c  --linelength=120 \
+            --filter=-readability/casting \
+            src/"$DIRECTORY"/*.c
+
         echo "--------------------"
         echo "------ *.cpp  ------"
         echo "--------------------"
-        code_linter/cpplint/cpplint.py  --linelength=120 --filter=-runtime/references src/"$DIRECTORY"/*.cpp
+        code_linter/cpplint/cpplint.py  --linelength=120 \
+            --filter=-runtime/references \
+            src/"$DIRECTORY"/*.cpp
         echo "--------------------"
         echo "------   C HEADER  ------"
         echo "--------------------"
@@ -89,11 +98,9 @@ else
         echo "--------------------"
         echo "------ C++ HEADER  ------"
         echo "--------------------"
-        code_linter/cpplint/cpplint.py  --extensions=hpp,h --headers=hpp  --linelength=120 --filter=-runtime/references include/"$DIRECTORY"/*.h*
-        echo "--------------------"
-        echo "------ this shouild fail  ------"
-        echo "--------------------"
-        code_linter/cpplint/cpplint.py src/"$DIRECTORY"/src/*.h*
+        code_linter/cpplint/cpplint.py  --extensions=hpp,h --headers=hpp,h  --linelength=120 \
+            --filter=-runtime/references \
+            include/"$DIRECTORY"/*.h*
     fi
 fi
 
